@@ -20,10 +20,9 @@ module Language.JavaScript.Parser
 
 
 import Language.JavaScript.Parser.AST
-import Language.JavaScript.Parser.ParseError
 import Language.JavaScript.Parser.Token
 import qualified Language.JavaScript.Parser.Parser as PA
---import Language.JavaScript.Parser.ParserMonad
+
 import Language.JavaScript.Parser.SrcLocation
 import Language.JavaScript.Pretty.Printer
 
