@@ -1,12 +1,12 @@
-module Language.JavaScript.Pretty.Printer (
-  -- * Printing
-  renderJS
-  , renderToString
-  ) where
+module Language.JavaScript.Pretty.Printer
+    ( -- * Printing
+      renderJS
+    , renderToString
+    ) where
 
 import Data.Char
 import Data.List
-import Data.Monoid (Monoid, mappend, mempty, mconcat)
+import Data.Monoid (Monoid, mappend, mempty)
 import Language.JavaScript.Parser.AST
 import Language.JavaScript.Parser.Parser
 import Language.JavaScript.Parser.SrcLocation
@@ -16,8 +16,6 @@ import qualified Blaze.ByteString.Builder.Char.Utf8 as BS
 import qualified Data.ByteString.Lazy as LB
 import qualified Codec.Binary.UTF8.String as US
 
-import Debug.Trace
-
 -- ---------------------------------------------------------------------
 
 data Foo = Foo (Int,Int) BB.Builder
@@ -28,14 +26,14 @@ data Foo = Foo (Int,Int) BB.Builder
 (<>) :: BB.Builder -> BB.Builder -> BB.Builder
 (<>) a b = mappend a b
 
-(<+>) :: BB.Builder -> BB.Builder -> BB.Builder
-(<+>) a b = mconcat [a, (text " "), b]
+-- (<+>) :: BB.Builder -> BB.Builder -> BB.Builder
+-- (<+>) a b = mconcat [a, (text " "), b]
 
 --() ((Int, Int), BB.Builder) -> ((Int, Int), BB.Builder) -> ((Int, Int), BB.Builder)
 --() a b =
 
-hcat :: (Monoid a) => [a] -> a
-hcat xs = mconcat xs
+-- hcat :: (Monoid a) => [a] -> a
+-- hcat xs = mconcat xs
 
 empty :: BB.Builder
 empty = mempty
@@ -43,20 +41,14 @@ empty = mempty
 text :: String -> BB.Builder
 text s = BS.fromString s
 
-char :: Char -> BB.Builder
-char c = BS.fromChar c
+-- char :: Char -> BB.Builder
+-- char c = BS.fromChar c
 
-comma :: BB.Builder
-comma = BS.fromChar ','
+-- comma :: BB.Builder
+-- comma = BS.fromChar ','
 
-punctuate :: a -> [a] -> [a]
-punctuate p xs = intersperse p xs
-
--- ---------------------------------------------------------------------
-
-(<!>) :: Foo -> Foo -> Foo
-(<!>) (Foo _ bb1) (Foo (r,c) bb2) = Foo (r,c) (mappend bb1 bb2)
---(<!>) a b = mappend a b
+-- punctuate :: a -> [a] -> [a]
+-- punctuate p xs = intersperse p xs
 
 -- ---------------------------------------------------------------------
 
@@ -83,7 +75,7 @@ rn (NN (JSArguments lb xs rb))                    foo = rJS ([lb] ++ xs ++ [rb])
 rn (NN (JSArrayLiteral lb xs rb))                 foo = rJS ([lb] ++ xs ++ [rb]) foo
 rn (NN (JSBlock lb x rb))                         foo = rJS (lb ++ x ++ rb) foo
 rn (NN (JSBreak b x1s as))                        foo = rJS ([b]++x1s++[as]) foo
-rn (NN (JSCallExpression s os xs cs))             foo = rJS (os ++ xs ++ cs) foo
+rn (NN (JSCallExpression _s os xs cs))            foo = rJS (os ++ xs ++ cs) foo
 rn (NN (JSCase ca x1 c x2s))                      foo = rJS ([ca,x1,c]++x2s) foo
 rn (NN (JSCatch c lb x1 x2s rb x3))               foo = rJS ([c,lb,x1]++x2s++[rb,x3]) foo
 rn (NN (JSContinue c xs as))                      foo = rJS ([c]++xs++[as]) foo
@@ -91,9 +83,9 @@ rn (NN (JSDefault d c xs))                        foo = rJS ([d,c]++xs) foo
 rn (NN (JSDoWhile d x1 w lb x2 rb x3))            foo = rJS ([d,x1,w,lb,x2,rb,x3]) foo
 rn (NN (JSElision c))                             foo = rJS [c] foo
 rn (NN (JSExpression xs))                         foo = rJS xs foo
-rn (NN (JSExpressionBinary s lhs op rhs))         foo = rJS (lhs ++ [op] ++ rhs) foo
+rn (NN (JSExpressionBinary _s lhs op rhs))        foo = rJS (lhs ++ [op] ++ rhs) foo
 rn (NN (JSExpressionParen lb e rb))               foo = rJS ([lb,e,rb]) foo
-rn (NN (JSExpressionPostfix s xs op))             foo = rJS (xs ++ [op]) foo
+rn (NN (JSExpressionPostfix _s xs op))            foo = rJS (xs ++ [op]) foo
 rn (NN (JSExpressionTernary cond h v1 c v2))      foo = rJS (cond ++[h] ++ v1 ++ [c] ++ v2) foo
 rn (NN (JSFinally f x))                           foo = rJS [f,x] foo
 rn (NN (JSFor f lb x1s s1 x2s s2 x3s rb x4))      foo = rJS ([f,lb]++x1s++[s1]++x2s++[s2]++x3s++[rb,x4]) foo
@@ -119,7 +111,7 @@ rn (NN (JSSourceElementsTop xs))                  foo = rJS xs foo
 rn (NN (JSSwitch s lb x rb x2))                   foo = rJS ([s,lb,x,rb,x2]) foo
 rn (NN (JSThrow t x))                             foo = rJS [t,x] foo
 rn (NN (JSTry t x1 x2s))                          foo = rJS ([t,x1]++x2s) foo
-rn (NN (JSUnary l n))                             foo = rJS [n] foo
+rn (NN (JSUnary _l n))                            foo = rJS [n] foo
 rn (NN (JSVarDecl x1 x2s))                        foo = rJS ([x1]++x2s) foo
 rn (NN (JSVariables n xs as))                     foo = rJS ([n]++xs++[as]) foo
 rn (NN (JSWhile w lb x1 rb x2))                   foo = rJS [w,lb,x1,rb,x2] foo
@@ -145,9 +137,9 @@ rc :: [CommentAnnotation] -> Foo -> Foo
 rc cs foo = foldl' go foo cs
   where
     go :: Foo -> CommentAnnotation -> Foo
-    go foo NoComment = foo
-    go foo (CommentA   p s) = rps p s foo
-    go foo (WhiteSpace p s) = rps p s foo
+    go bar NoComment = bar
+    go bar (CommentA   p s) = rps p s bar
+    go bar (WhiteSpace p s) = rps p s bar
 
 -- Render a string at the given position
 rps :: TokenPosn -> String -> Foo -> Foo
@@ -159,11 +151,11 @@ rps p s foo = (rs s foo')
 rs :: String -> Foo -> Foo
 rs s (Foo (r,c) bb) = (Foo (r',c') (bb <> (text s)))
   where
-    (r',c') = foldl' (\(row,col) char -> go (row,col) char) (r,c) s
+    (r',c') = foldl' (\(row,col) ch -> go (row,col) ch) (r,c) s
 
-    go (r,c) '\n' = (r+1,1)
-    go (r,c) '\t' = (r,c+8)
-    go (r,c) _    = (r,c+1)
+    go (r'',_)   '\n' = (r''+1,1)
+    go (r'',c'') '\t' = (r'',c''+8)
+    go (r'',c'') _    = (r'',c''+1)
 
 
 goto :: TokenPosn -> Foo -> Foo
@@ -196,6 +188,7 @@ _t str = _r $ readJs str
 
 
 -- readJs "/*a*/x"
+_ax :: JSNode
 _ax = (NN
      (JSExpression
        [NT
@@ -208,6 +201,7 @@ _ax = (NN
 -- readJs "//j\nthis_"
 -- NS (JSSourceElementsTop [NS (JSExpression [NS (JSIdentifier "this_") (TokenPn 4 2 1) [CommentA (TokenPn 0 1 1) "//j"]]) (TokenPn 4 2 1) []]) (TokenPn 4 2 1) []
 
+_r1 :: JSNode
 _r1 = NN
       (
         JSExpression
